# Pekora

[![PyPI](https://img.shields.io/pypi/v/pekora?logo=pypi&color=green&logoColor=white&style=for-the-badge)](https://pypi.org/project/pekora)
[![PyPI - License](https://img.shields.io/pypi/l/pekora?color=03cb98&style=for-the-badge)](https://github.com/celsiusnarhwal/pekora/blob/main/LICENSE.md)
[![Code style: Black](https://aegis.celsiusnarhwal.dev/badge/black?style=for-the-badge)](https://github.com/psf/black)

Pekora is a calculator for Discord permission values. With it, you can calculate permission values, see detailed
information about the permissions a value represents, and interactively build your own
permissions.

## Installation

### pipx (recommended)

[Install pipx](https://pypa.github.io/pipx/installation/), then run:

```bash
pipx install pekora
```

### Homebrew (macOS and Linux only)

[Homebrew](https://brew.sh) users can install Pekora from the
[Houkago Tea Tap](https://github.com/celsiusnarhwal/homebrew-htt).

```bash
brew tap celsiusnarhwal/htt
brew install pekora
```

## Documentation

For documentation, including usage instructions, visit [Pekora's website](https://pekora.celsiusnarhwal.dev).

## License

Pekora is licensed under the [MIT License](https://github.com/celsiusnarhwal/pekora/blob/main/LICENSE.md). Its
documentation is licensed under [CC BY 4.0](https://pekora.celsiusnarhwal.dev/license).
